Author:

* [Anthony Brown (Leiden Observatory)](http://www.strw.leidenuniv.nl/~brown)

Gaia performance modelling from:

* [Gaia Science Performance pages](https://www.cosmos.esa.int/web/gaia/science-performance)

Direct contributions to the code base:

Comments, corrections & suggestions:
